.. toctree::

ManageSF REST API
=================

The manageSF REST API v2 is described in the OpenAPI format in docs/swagger/managesf.v2.yaml

A full description of the API can be found on swaggerhub: https://app.swaggerhub.com/apis/mhuin/manageSFv2.0/2.0
